Coverage for tictactoe/contest/fixtures: 100%

# Coverage for tictactoe/contest/fixtures : 100%

## 7 statements 7 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 | from django.contrib.auth.models import User from tictactoelib.examples import dumb_player def qualification_bot(sender, **kwargs): from .models import Entry (q, created) = User.objects.get_or_create(username='Qualification-Bot') if Entry.objects.filter(user=q).first() is None: Entry.objects.create(user=q, code=dumb_player)